#!/usr/bin/env bash
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.


bin=`dirname "$0"`
bin=`cd "$bin"; pwd`
. "$bin"/impala-config.sh > /dev/null 2>&1

# Generate list of files for Cscope to index.
# -ignore_readdir_race: this scripts runs in parallel with other build steps, so races
# with unrelated directories being deleted are possible (IMPALA-6363).
cd $IMPALA_HOME
find . -ignore_readdir_race -regex '.*\.\(cc\|c\|hh\|h\|java\|thrift\|flex\|y\)$' \
    > cscope.files

